@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.MediaTailor 1.25.1\nVersion:         1.25.1\nBuilder version:"
-        " 7.11.10\nDocs:           "
+        "Type annotations for boto3.MediaTailor 1.26.0\nVersion:         1.26.0.post1\nBuilder"
+        " version: 7.11.10\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.25.1")
+    print("1.26.0.post1")
 
 
 def main() -> None:
