@@ -138,7 +138,7 @@ class MediaTailorClient(BaseClient):
         self, *, PercentEnabled: int, PlaybackConfigurationName: str
     ) -> ConfigureLogsForPlaybackConfigurationResponseTypeDef:
         """
-        Configures Amazon CloudWatch log settings for a playback configuration.
+        Amazon CloudWatch log settings for a playback configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.configure_logs_for_playback_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#configure_logs_for_playback_configuration)
@@ -170,7 +170,7 @@ class MediaTailorClient(BaseClient):
         Tags: Mapping[str, str] = ...
     ) -> CreateLiveSourceResponseTypeDef:
         """
-        Creates name for a specific live source in a source location.
+        The live source configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.create_live_source)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#create_live_source)
@@ -186,7 +186,7 @@ class MediaTailorClient(BaseClient):
         StreamId: str = ...
     ) -> CreatePrefetchScheduleResponseTypeDef:
         """
-        Creates a new prefetch schedule for the specified playback configuration.
+        Creates a prefetch schedule for a playback configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.create_prefetch_schedule)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#create_prefetch_schedule)
@@ -204,7 +204,7 @@ class MediaTailorClient(BaseClient):
         VodSourceName: str = ...
     ) -> CreateProgramResponseTypeDef:
         """
-        Creates a program.
+        Creates a program within a channel.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.create_program)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#create_program)
@@ -221,7 +221,7 @@ class MediaTailorClient(BaseClient):
         Tags: Mapping[str, str] = ...
     ) -> CreateSourceLocationResponseTypeDef:
         """
-        Creates a source location on a specific channel.
+        Creates a source location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#create_source_location)
@@ -236,7 +236,7 @@ class MediaTailorClient(BaseClient):
         Tags: Mapping[str, str] = ...
     ) -> CreateVodSourceResponseTypeDef:
         """
-        Creates name for a specific VOD source in a source location.
+        The VOD source configuration parameters.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#create_vod_source)
@@ -252,7 +252,7 @@ class MediaTailorClient(BaseClient):
 
     def delete_channel_policy(self, *, ChannelName: str) -> Dict[str, Any]:
         """
-        Deletes a channel's IAM policy.
+        The channel policy to delete.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#delete_channel_policy)
@@ -260,7 +260,7 @@ class MediaTailorClient(BaseClient):
 
     def delete_live_source(self, *, LiveSourceName: str, SourceLocationName: str) -> Dict[str, Any]:
         """
-        Deletes a specific live source in a specific source location.
+        The live source to delete.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.delete_live_source)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#delete_live_source)
@@ -268,7 +268,7 @@ class MediaTailorClient(BaseClient):
 
     def delete_playback_configuration(self, *, Name: str) -> Dict[str, Any]:
         """
-        Deletes the playback configuration for the specified name.
+        Deletes a playback configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#delete_playback_configuration)
@@ -286,7 +286,7 @@ class MediaTailorClient(BaseClient):
 
     def delete_program(self, *, ChannelName: str, ProgramName: str) -> Dict[str, Any]:
         """
-        Deletes a specific program on a specific channel.
+        Deletes a program within a channel.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#delete_program)
@@ -294,7 +294,7 @@ class MediaTailorClient(BaseClient):
 
     def delete_source_location(self, *, SourceLocationName: str) -> Dict[str, Any]:
         """
-        Deletes a source location on a specific channel.
+        Deletes a source location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#delete_source_location)
@@ -302,7 +302,7 @@ class MediaTailorClient(BaseClient):
 
     def delete_vod_source(self, *, SourceLocationName: str, VodSourceName: str) -> Dict[str, Any]:
         """
-        Deletes a specific VOD source in a specific source location.
+        The video on demand (VOD) source to delete.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#delete_vod_source)
@@ -310,7 +310,7 @@ class MediaTailorClient(BaseClient):
 
     def describe_channel(self, *, ChannelName: str) -> DescribeChannelResponseTypeDef:
         """
-        Describes the properties of a specific channel.
+        Describes a channel.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#describe_channel)
@@ -320,7 +320,7 @@ class MediaTailorClient(BaseClient):
         self, *, LiveSourceName: str, SourceLocationName: str
     ) -> DescribeLiveSourceResponseTypeDef:
         """
-        Provides details about a specific live source in a specific source location.
+        The live source to describe.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.describe_live_source)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#describe_live_source)
@@ -330,7 +330,7 @@ class MediaTailorClient(BaseClient):
         self, *, ChannelName: str, ProgramName: str
     ) -> DescribeProgramResponseTypeDef:
         """
-        Retrieves the properties of the requested program.
+        Describes a program within a channel.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#describe_program)
@@ -340,7 +340,7 @@ class MediaTailorClient(BaseClient):
         self, *, SourceLocationName: str
     ) -> DescribeSourceLocationResponseTypeDef:
         """
-        Retrieves the properties of the requested source location.
+        Describes a source location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#describe_source_location)
@@ -350,7 +350,8 @@ class MediaTailorClient(BaseClient):
         self, *, SourceLocationName: str, VodSourceName: str
     ) -> DescribeVodSourceResponseTypeDef:
         """
-        Provides details about a specific VOD source in a specific source location.
+        Provides details about a specific video on demand (VOD) source in a specific
+        source location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#describe_vod_source)
@@ -372,7 +373,7 @@ class MediaTailorClient(BaseClient):
 
     def get_channel_policy(self, *, ChannelName: str) -> GetChannelPolicyResponseTypeDef:
         """
-        Retrieves information about a channel's IAM policy.
+        Returns the channel's IAM policy.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#get_channel_policy)
@@ -395,7 +396,7 @@ class MediaTailorClient(BaseClient):
 
     def get_playback_configuration(self, *, Name: str) -> GetPlaybackConfigurationResponseTypeDef:
         """
-        Returns the playback configuration for the specified name.
+        Retrieves a playback configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#get_playback_configuration)
@@ -405,8 +406,7 @@ class MediaTailorClient(BaseClient):
         self, *, Name: str, PlaybackConfigurationName: str
     ) -> GetPrefetchScheduleResponseTypeDef:
         """
-        Returns information about the prefetch schedule for a specific playback
-        configuration.
+        Retrieves a prefetch schedule for a playback configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.get_prefetch_schedule)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#get_prefetch_schedule)
@@ -416,7 +416,8 @@ class MediaTailorClient(BaseClient):
         self, *, ResourceArn: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListAlertsResponseTypeDef:
         """
-        Returns a list of alerts for the given resource.
+        Lists the alerts that are associated with a MediaTailor channel assembly
+        resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_alerts)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_alerts)
@@ -426,7 +427,8 @@ class MediaTailorClient(BaseClient):
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListChannelsResponseTypeDef:
         """
-        Retrieves a list of channels that are associated with this account.
+        Retrieves information about the channels that are associated with the current
+        AWS account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_channels)
@@ -436,7 +438,7 @@ class MediaTailorClient(BaseClient):
         self, *, SourceLocationName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListLiveSourcesResponseTypeDef:
         """
-        lists all the live sources in a source location.
+        Lists the live sources contained in a source location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_live_sources)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_live_sources)
@@ -446,8 +448,7 @@ class MediaTailorClient(BaseClient):
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListPlaybackConfigurationsResponseTypeDef:
         """
-        Returns a list of the playback configurations defined in AWS Elemental
-        MediaTailor.
+        Retrieves existing playback configurations.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_playback_configurations)
@@ -462,7 +463,7 @@ class MediaTailorClient(BaseClient):
         StreamId: str = ...
     ) -> ListPrefetchSchedulesResponseTypeDef:
         """
-        Creates a new prefetch schedule.
+        Lists the prefetch schedules for a playback configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_prefetch_schedules)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_prefetch_schedules)
@@ -472,7 +473,7 @@ class MediaTailorClient(BaseClient):
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListSourceLocationsResponseTypeDef:
         """
-        Retrieves a list of source locations.
+        Lists the source locations for a channel.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_source_locations)
@@ -480,8 +481,7 @@ class MediaTailorClient(BaseClient):
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        Returns a list of the tags assigned to the specified playback configuration
-        resource.
+        A list of tags that are associated with this resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_tags_for_resource)
@@ -491,7 +491,7 @@ class MediaTailorClient(BaseClient):
         self, *, SourceLocationName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListVodSourcesResponseTypeDef:
         """
-        Lists all the VOD sources in a source location.
+        Lists the VOD sources contained in a source location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#list_vod_sources)
@@ -508,6 +508,7 @@ class MediaTailorClient(BaseClient):
     def put_playback_configuration(
         self,
         *,
+        Name: str,
         AdDecisionServerUrl: str = ...,
         AvailSuppression: AvailSuppressionTypeDef = ...,
         Bumper: BumperTypeDef = ...,
@@ -516,7 +517,6 @@ class MediaTailorClient(BaseClient):
         DashConfiguration: DashConfigurationForPutTypeDef = ...,
         LivePreRollConfiguration: LivePreRollConfigurationTypeDef = ...,
         ManifestProcessingRules: ManifestProcessingRulesTypeDef = ...,
-        Name: str = ...,
         PersonalizationThresholdSeconds: int = ...,
         SlateAdUrl: str = ...,
         Tags: Mapping[str, str] = ...,
@@ -524,7 +524,7 @@ class MediaTailorClient(BaseClient):
         VideoContentSourceUrl: str = ...
     ) -> PutPlaybackConfigurationResponseTypeDef:
         """
-        Adds a new playback configuration to AWS Elemental MediaTailor.
+        Creates a playback configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#put_playback_configuration)
@@ -532,7 +532,7 @@ class MediaTailorClient(BaseClient):
 
     def start_channel(self, *, ChannelName: str) -> Dict[str, Any]:
         """
-        Starts a specific channel.
+        Starts a channel.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#start_channel)
@@ -540,7 +540,7 @@ class MediaTailorClient(BaseClient):
 
     def stop_channel(self, *, ChannelName: str) -> Dict[str, Any]:
         """
-        Stops a specific channel.
+        Stops a channel.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#stop_channel)
@@ -550,7 +550,7 @@ class MediaTailorClient(BaseClient):
         self, *, ResourceArn: str, Tags: Mapping[str, str]
     ) -> EmptyResponseMetadataTypeDef:
         """
-        Adds tags to the specified playback configuration resource.
+        The resource to tag.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#tag_resource)
@@ -560,7 +560,7 @@ class MediaTailorClient(BaseClient):
         self, *, ResourceArn: str, TagKeys: Sequence[str]
     ) -> EmptyResponseMetadataTypeDef:
         """
-        Removes tags from the specified playback configuration resource.
+        The resource to untag.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#untag_resource)
@@ -574,7 +574,7 @@ class MediaTailorClient(BaseClient):
         FillerSlate: SlateSourceTypeDef = ...
     ) -> UpdateChannelResponseTypeDef:
         """
-        Updates an existing channel.
+        Updates a channel.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#update_channel)
@@ -588,7 +588,7 @@ class MediaTailorClient(BaseClient):
         SourceLocationName: str
     ) -> UpdateLiveSourceResponseTypeDef:
         """
-        Updates a specific live source in a specific source location.
+        Updates a live source's configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.update_live_source)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#update_live_source)
@@ -604,7 +604,7 @@ class MediaTailorClient(BaseClient):
         SegmentDeliveryConfigurations: Sequence[SegmentDeliveryConfigurationTypeDef] = ...
     ) -> UpdateSourceLocationResponseTypeDef:
         """
-        Updates a source location on a specific channel.
+        Updates a source location.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#update_source_location)
@@ -618,7 +618,7 @@ class MediaTailorClient(BaseClient):
         VodSourceName: str
     ) -> UpdateVodSourceResponseTypeDef:
         """
-        Updates a specific VOD source in a specific source location.
+        Updates a VOD source's configuration.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#update_vod_source)
