@@ -57,7 +57,7 @@ ListPlaybackConfigurationsPaginatorName = Literal["list_playback_configurations"
 ListPrefetchSchedulesPaginatorName = Literal["list_prefetch_schedules"]
 ListSourceLocationsPaginatorName = Literal["list_source_locations"]
 ListVodSourcesPaginatorName = Literal["list_vod_sources"]
-MessageTypeType = Literal["SPLICE_INSERT"]
+MessageTypeType = Literal["SPLICE_INSERT", "TIME_SIGNAL"]
 ModeType = Literal["BEHIND_LIVE_EDGE", "OFF"]
 OperatorType = Literal["EQUALS"]
 OriginManifestTypeType = Literal["MULTI_PERIOD", "SINGLE_PERIOD"]
