@@ -18,6 +18,7 @@ from typing import Dict, List, Mapping, Sequence, Union
 from .literals import (
     AccessTypeType,
     ChannelStateType,
+    MessageTypeType,
     ModeType,
     OriginManifestTypeType,
     PlaybackModeType,
@@ -90,12 +91,12 @@ __all__ = (
     "PutChannelPolicyRequestRequestTypeDef",
     "ScheduleAdBreakTypeDef",
     "TransitionTypeDef",
+    "SegmentationDescriptorTypeDef",
     "StartChannelRequestRequestTypeDef",
     "StopChannelRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "AccessConfigurationTypeDef",
-    "AdBreakTypeDef",
     "ManifestProcessingRulesTypeDef",
     "PrefetchConsumptionTypeDef",
     "ConfigureLogsForPlaybackConfigurationResponseTypeDef",
@@ -127,14 +128,13 @@ __all__ = (
     "ResponseOutputItemTypeDef",
     "ScheduleEntryTypeDef",
     "ScheduleConfigurationTypeDef",
+    "TimeSignalMessageTypeDef",
     "CreateSourceLocationRequestRequestTypeDef",
     "CreateSourceLocationResponseTypeDef",
     "DescribeSourceLocationResponseTypeDef",
     "SourceLocationTypeDef",
     "UpdateSourceLocationRequestRequestTypeDef",
     "UpdateSourceLocationResponseTypeDef",
-    "CreateProgramResponseTypeDef",
-    "DescribeProgramResponseTypeDef",
     "GetPlaybackConfigurationResponseTypeDef",
     "PlaybackConfigurationTypeDef",
     "PutPlaybackConfigurationRequestRequestTypeDef",
@@ -152,11 +152,14 @@ __all__ = (
     "DescribeChannelResponseTypeDef",
     "UpdateChannelResponseTypeDef",
     "GetChannelScheduleResponseTypeDef",
-    "CreateProgramRequestRequestTypeDef",
+    "AdBreakTypeDef",
     "ListSourceLocationsResponseTypeDef",
     "ListPlaybackConfigurationsResponseTypeDef",
     "ListPrefetchSchedulesResponseTypeDef",
     "ListChannelsResponseTypeDef",
+    "CreateProgramRequestRequestTypeDef",
+    "CreateProgramResponseTypeDef",
+    "DescribeProgramResponseTypeDef",
 )
 
 SecretsManagerAccessTokenConfigurationTypeDef = TypedDict(
@@ -698,6 +701,21 @@ class TransitionTypeDef(_RequiredTransitionTypeDef, _OptionalTransitionTypeDef):
     pass
 
 
+SegmentationDescriptorTypeDef = TypedDict(
+    "SegmentationDescriptorTypeDef",
+    {
+        "SegmentNum": int,
+        "SegmentationEventId": int,
+        "SegmentationTypeId": int,
+        "SegmentationUpid": str,
+        "SegmentationUpidType": int,
+        "SegmentsExpected": int,
+        "SubSegmentNum": int,
+        "SubSegmentsExpected": int,
+    },
+    total=False,
+)
+
 StartChannelRequestRequestTypeDef = TypedDict(
     "StartChannelRequestRequestTypeDef",
     {
@@ -737,17 +755,6 @@ AccessConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-AdBreakTypeDef = TypedDict(
-    "AdBreakTypeDef",
-    {
-        "MessageType": Literal["SPLICE_INSERT"],
-        "OffsetMillis": int,
-        "Slate": SlateSourceTypeDef,
-        "SpliceInsertMessage": SpliceInsertMessageTypeDef,
-    },
-    total=False,
-)
-
 ManifestProcessingRulesTypeDef = TypedDict(
     "ManifestProcessingRulesTypeDef",
     {
@@ -1232,6 +1239,14 @@ ScheduleConfigurationTypeDef = TypedDict(
     },
 )
 
+TimeSignalMessageTypeDef = TypedDict(
+    "TimeSignalMessageTypeDef",
+    {
+        "SegmentationDescriptors": Sequence[SegmentationDescriptorTypeDef],
+    },
+    total=False,
+)
+
 _RequiredCreateSourceLocationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateSourceLocationRequestRequestTypeDef",
     {
@@ -1357,38 +1372,6 @@ UpdateSourceLocationResponseTypeDef = TypedDict(
     },
 )
 
-CreateProgramResponseTypeDef = TypedDict(
-    "CreateProgramResponseTypeDef",
-    {
-        "AdBreaks": List[AdBreakTypeDef],
-        "Arn": str,
-        "ChannelName": str,
-        "CreationTime": datetime,
-        "LiveSourceName": str,
-        "ProgramName": str,
-        "ScheduledStartTime": datetime,
-        "SourceLocationName": str,
-        "VodSourceName": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
-DescribeProgramResponseTypeDef = TypedDict(
-    "DescribeProgramResponseTypeDef",
-    {
-        "AdBreaks": List[AdBreakTypeDef],
-        "Arn": str,
-        "ChannelName": str,
-        "CreationTime": datetime,
-        "LiveSourceName": str,
-        "ProgramName": str,
-        "ScheduledStartTime": datetime,
-        "SourceLocationName": str,
-        "VodSourceName": str,
-        "ResponseMetadata": ResponseMetadataTypeDef,
-    },
-)
-
 GetPlaybackConfigurationResponseTypeDef = TypedDict(
     "GetPlaybackConfigurationResponseTypeDef",
     {
@@ -1727,32 +1710,18 @@ GetChannelScheduleResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateProgramRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateProgramRequestRequestTypeDef",
+AdBreakTypeDef = TypedDict(
+    "AdBreakTypeDef",
     {
-        "ChannelName": str,
-        "ProgramName": str,
-        "ScheduleConfiguration": ScheduleConfigurationTypeDef,
-        "SourceLocationName": str,
-    },
-)
-_OptionalCreateProgramRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateProgramRequestRequestTypeDef",
-    {
-        "AdBreaks": Sequence[AdBreakTypeDef],
-        "LiveSourceName": str,
-        "VodSourceName": str,
+        "MessageType": MessageTypeType,
+        "OffsetMillis": int,
+        "Slate": SlateSourceTypeDef,
+        "SpliceInsertMessage": SpliceInsertMessageTypeDef,
+        "TimeSignalMessage": TimeSignalMessageTypeDef,
     },
     total=False,
 )
 
-
-class CreateProgramRequestRequestTypeDef(
-    _RequiredCreateProgramRequestRequestTypeDef, _OptionalCreateProgramRequestRequestTypeDef
-):
-    pass
-
-
 ListSourceLocationsResponseTypeDef = TypedDict(
     "ListSourceLocationsResponseTypeDef",
     {
@@ -1788,3 +1757,61 @@ ListChannelsResponseTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
+
+_RequiredCreateProgramRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProgramRequestRequestTypeDef",
+    {
+        "ChannelName": str,
+        "ProgramName": str,
+        "ScheduleConfiguration": ScheduleConfigurationTypeDef,
+        "SourceLocationName": str,
+    },
+)
+_OptionalCreateProgramRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProgramRequestRequestTypeDef",
+    {
+        "AdBreaks": Sequence[AdBreakTypeDef],
+        "LiveSourceName": str,
+        "VodSourceName": str,
+    },
+    total=False,
+)
+
+
+class CreateProgramRequestRequestTypeDef(
+    _RequiredCreateProgramRequestRequestTypeDef, _OptionalCreateProgramRequestRequestTypeDef
+):
+    pass
+
+
+CreateProgramResponseTypeDef = TypedDict(
+    "CreateProgramResponseTypeDef",
+    {
+        "AdBreaks": List[AdBreakTypeDef],
+        "Arn": str,
+        "ChannelName": str,
+        "CreationTime": datetime,
+        "LiveSourceName": str,
+        "ProgramName": str,
+        "ScheduledStartTime": datetime,
+        "SourceLocationName": str,
+        "VodSourceName": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeProgramResponseTypeDef = TypedDict(
+    "DescribeProgramResponseTypeDef",
+    {
+        "AdBreaks": List[AdBreakTypeDef],
+        "Arn": str,
+        "ChannelName": str,
+        "CreationTime": datetime,
+        "LiveSourceName": str,
+        "ProgramName": str,
+        "ScheduledStartTime": datetime,
+        "SourceLocationName": str,
+        "VodSourceName": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
